# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.contact_element import ContactElement
from ..types.element import Element
from ..types.entry import Entry
from ..types.header_element import HeaderElement
from ..types.idempotency_key import IdempotencyKey
from ..types.invoice_element import InvoiceElement
from ..types.label_element import LabelElement
from ..types.method_element import MethodElement
from ..types.note_element import NoteElement
from ..types.page_element import PageElement
from ..types.pagelink_setting import PagelinkSetting
from ..types.payor_element import PayorElement
from ..types.push_pay_link_request import PushPayLinkRequest
from .raw_client import AsyncRawPaymentLinkClient, RawPaymentLinkClient
from .types.get_pay_link_from_id_response import GetPayLinkFromIdResponse
from .types.payabli_api_response_payment_links import PayabliApiResponsePaymentLinks

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class PaymentLinkClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawPaymentLinkClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawPaymentLinkClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawPaymentLinkClient
        """
        return self._raw_client

    def add_pay_link_from_invoice(
        self,
        id_invoice: int,
        *,
        amount_fixed: typing.Optional[bool] = None,
        mail_2: typing.Optional[str] = None,
        idempotency_key: typing.Optional[IdempotencyKey] = None,
        contact_us: typing.Optional[ContactElement] = OMIT,
        invoices: typing.Optional[InvoiceElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        payor: typing.Optional[PayorElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Generates a payment link for an invoice from the invoice ID.

        Parameters
        ----------
        id_invoice : int
            Invoice ID

        amount_fixed : typing.Optional[bool]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        idempotency_key : typing.Optional[IdempotencyKey]

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        invoices : typing.Optional[InvoiceElement]
            Invoices section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        payor : typing.Optional[PayorElement]
            Customer/Payor section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import (
            ContactElement,
            Element,
            FileContent,
            HeaderElement,
            InvoiceElement,
            LabelElement,
            MethodElement,
            MethodElementSettings,
            MethodElementSettingsApplePay,
            MethodsList,
            NoteElement,
            PageElement,
            PagelinkSetting,
            PayorElement,
            PayorFields,
            payabli,
        )

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.add_pay_link_from_invoice(
            id_invoice=23548884,
            mail_2="jo@example.com; ceo@example.com",
            contact_us=ContactElement(
                email_label="Email",
                enabled=True,
                header="Contact Us",
                order=0,
                payment_icons=True,
                phone_label="Phone",
            ),
            invoices=InvoiceElement(
                enabled=True,
                invoice_link=LabelElement(
                    enabled=True,
                    label="View Invoice",
                    order=0,
                ),
                order=0,
                view_invoice_details=LabelElement(
                    enabled=True,
                    label="Invoice Details",
                    order=0,
                ),
            ),
            logo=Element(
                enabled=True,
                order=0,
            ),
            message_before_paying=LabelElement(
                enabled=True,
                label="Please review your payment details",
                order=0,
            ),
            notes=NoteElement(
                enabled=True,
                header="Additional Notes",
                order=0,
                placeholder="Enter any additional notes here",
                value="",
            ),
            page=PageElement(
                description="Complete your payment securely",
                enabled=True,
                header="Payment Page",
                order=0,
            ),
            payment_button=LabelElement(
                enabled=True,
                label="Pay Now",
                order=0,
            ),
            payment_methods=MethodElement(
                all_methods_checked=True,
                enabled=True,
                header="Payment Methods",
                methods=MethodsList(
                    amex=True,
                    apple_pay=True,
                    discover=True,
                    e_check=True,
                    mastercard=True,
                    visa=True,
                ),
                order=0,
                settings=MethodElementSettings(
                    apple_pay=MethodElementSettingsApplePay(
                        button_style="black",
                        button_type="pay",
                        language="en-US",
                    ),
                ),
            ),
            payor=PayorElement(
                enabled=True,
                fields=[
                    PayorFields(
                        display=True,
                        fixed=True,
                        identifier=True,
                        label="Full Name",
                        name="fullName",
                        order=0,
                        required=True,
                        validation="^[a-zA-Z ]+$",
                        value="",
                        width=0,
                    )
                ],
                header="Payor Information",
                order=0,
            ),
            review=HeaderElement(
                enabled=True,
                header="Review Payment",
                order=0,
            ),
            settings=PagelinkSetting(
                color="#000000",
                custom_css_url="https://example.com/custom.css",
                language="en",
                page_logo=FileContent(
                    f_content=" ",
                    filename="logo.jpg",
                    ftype="jpg",
                    furl="",
                ),
                redirect_after_approve=True,
                redirect_after_approve_url="https://example.com/success",
            ),
        )
        """
        _response = self._raw_client.add_pay_link_from_invoice(
            id_invoice,
            amount_fixed=amount_fixed,
            mail_2=mail_2,
            idempotency_key=idempotency_key,
            contact_us=contact_us,
            invoices=invoices,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            payor=payor,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data

    def add_pay_link_from_bill(
        self,
        bill_id: int,
        *,
        amount_fixed: typing.Optional[bool] = None,
        mail_2: typing.Optional[str] = None,
        idempotency_key: typing.Optional[IdempotencyKey] = None,
        contact_us: typing.Optional[ContactElement] = OMIT,
        invoices: typing.Optional[InvoiceElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        payor: typing.Optional[PayorElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Generates a payment link for a bill from the bill ID.

        Parameters
        ----------
        bill_id : int
            The Payabli ID for the bill.

        amount_fixed : typing.Optional[bool]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        idempotency_key : typing.Optional[IdempotencyKey]

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        invoices : typing.Optional[InvoiceElement]
            Invoices section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        payor : typing.Optional[PayorElement]
            Customer/Payor section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import (
            ContactElement,
            Element,
            HeaderElement,
            LabelElement,
            MethodElement,
            MethodsList,
            NoteElement,
            PageElement,
            PagelinkSetting,
            PayorElement,
            PayorFields,
            payabli,
        )

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.add_pay_link_from_bill(
            bill_id=23548884,
            mail_2="jo@example.com; ceo@example.com",
            contact_us=ContactElement(
                email_label="Email",
                enabled=True,
                header="Contact Us",
                order=0,
                payment_icons=True,
                phone_label="Phone",
            ),
            logo=Element(
                enabled=True,
                order=0,
            ),
            message_before_paying=LabelElement(
                enabled=True,
                label="Please review your payment details",
                order=0,
            ),
            notes=NoteElement(
                enabled=True,
                header="Additional Notes",
                order=0,
                placeholder="Enter any additional notes here",
                value="",
            ),
            page=PageElement(
                description="Get paid securely",
                enabled=True,
                header="Payment Page",
                order=0,
            ),
            payment_button=LabelElement(
                enabled=True,
                label="Pay Now",
                order=0,
            ),
            payment_methods=MethodElement(
                all_methods_checked=True,
                enabled=True,
                header="Payment Methods",
                methods=MethodsList(
                    amex=True,
                    apple_pay=True,
                    discover=True,
                    e_check=True,
                    mastercard=True,
                    visa=True,
                ),
                order=0,
            ),
            payor=PayorElement(
                enabled=True,
                fields=[
                    PayorFields(
                        display=True,
                        fixed=True,
                        identifier=True,
                        label="Full Name",
                        name="fullName",
                        order=0,
                        required=True,
                        validation="^[a-zA-Z ]+$",
                        value="",
                        width=0,
                    )
                ],
                header="Payor Information",
                order=0,
            ),
            review=HeaderElement(
                enabled=True,
                header="Review Payment",
                order=0,
            ),
            settings=PagelinkSetting(
                color="#000000",
                language="en",
            ),
        )
        """
        _response = self._raw_client.add_pay_link_from_bill(
            bill_id,
            amount_fixed=amount_fixed,
            mail_2=mail_2,
            idempotency_key=idempotency_key,
            contact_us=contact_us,
            invoices=invoices,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            payor=payor,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data

    def delete_pay_link_from_id(
        self, pay_link_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> PayabliApiResponsePaymentLinks:
        """
        Deletes a payment link by ID.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.delete_pay_link_from_id(
            pay_link_id="payLinkId",
        )
        """
        _response = self._raw_client.delete_pay_link_from_id(pay_link_id, request_options=request_options)
        return _response.data

    def get_pay_link_from_id(
        self, paylink_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetPayLinkFromIdResponse:
        """
        Retrieves a payment link by ID.

        Parameters
        ----------
        paylink_id : str
            ID for payment link

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetPayLinkFromIdResponse
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.get_pay_link_from_id(
            paylink_id="paylinkId",
        )
        """
        _response = self._raw_client.get_pay_link_from_id(paylink_id, request_options=request_options)
        return _response.data

    def push_pay_link_from_id(
        self, pay_link_id: str, *, request: PushPayLinkRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> PayabliApiResponsePaymentLinks:
        """
        Send a payment link to the specified email addresses or phone numbers.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        request : PushPayLinkRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import PushPayLinkRequest_Sms, payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.push_pay_link_from_id(
            pay_link_id="payLinkId",
            request=PushPayLinkRequest_Sms(),
        )
        """
        _response = self._raw_client.push_pay_link_from_id(
            pay_link_id, request=request, request_options=request_options
        )
        return _response.data

    def refresh_pay_link_from_id(
        self,
        pay_link_id: str,
        *,
        amount_fixed: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Refresh a payment link's content after an update.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        amount_fixed : typing.Optional[bool]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.refresh_pay_link_from_id(
            pay_link_id="payLinkId",
        )
        """
        _response = self._raw_client.refresh_pay_link_from_id(
            pay_link_id, amount_fixed=amount_fixed, request_options=request_options
        )
        return _response.data

    def send_pay_link_from_id(
        self,
        pay_link_id: str,
        *,
        attachfile: typing.Optional[bool] = None,
        mail_2: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Sends a payment link to the specified email addresses.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        attachfile : typing.Optional[bool]
            When `true`, attaches a PDF version of invoice to the email.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.send_pay_link_from_id(
            pay_link_id="payLinkId",
            mail_2="jo@example.com; ceo@example.com",
        )
        """
        _response = self._raw_client.send_pay_link_from_id(
            pay_link_id, attachfile=attachfile, mail_2=mail_2, request_options=request_options
        )
        return _response.data

    def update_pay_link_from_id(
        self,
        pay_link_id: str,
        *,
        contact_us: typing.Optional[ContactElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Updates a payment link's details.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import LabelElement, NoteElement, payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.update_pay_link_from_id(
            pay_link_id="332-c277b704-1301",
            notes=NoteElement(
                enabled=True,
                header="Additional Notes",
                order=0,
                placeholder="Enter any additional notes here",
                value="",
            ),
            payment_button=LabelElement(
                enabled=True,
                label="Pay Now",
                order=0,
            ),
        )
        """
        _response = self._raw_client.update_pay_link_from_id(
            pay_link_id,
            contact_us=contact_us,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data

    def add_pay_link_from_bill_lot_number(
        self,
        lot_number: str,
        *,
        entry_point: Entry,
        vendor_number: str,
        mail_2: typing.Optional[str] = None,
        amount_fixed: typing.Optional[str] = None,
        contact_us: typing.Optional[ContactElement] = OMIT,
        invoices: typing.Optional[InvoiceElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        payor: typing.Optional[PayorElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Generates a vendor payment link for a specific bill lot number. This allows you to pay all bills with the same lot number for a vendor with a single payment link.

        Parameters
        ----------
        lot_number : str
            Lot number of the bills to pay. All bills with this lot number will be included.

        entry_point : Entry

        vendor_number : str
            The vendor number for the vendor being paid with this payment link.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        amount_fixed : typing.Optional[str]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        invoices : typing.Optional[InvoiceElement]
            Invoices section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        payor : typing.Optional[PayorElement]
            Customer/Payor section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        from payabli import (
            ContactElement,
            Element,
            HeaderElement,
            LabelElement,
            MethodElement,
            MethodsList,
            NoteElement,
            PageElement,
            PagelinkSetting,
            PayorElement,
            PayorFields,
            payabli,
        )

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.payment_link.add_pay_link_from_bill_lot_number(
            lot_number="LOT-2024-001",
            entry_point="billing",
            vendor_number="VENDOR-123",
            mail_2="customer@example.com; billing@example.com",
            amount_fixed="true",
            contact_us=ContactElement(
                email_label="Email",
                enabled=True,
                header="Contact Us",
                order=0,
                payment_icons=True,
                phone_label="Phone",
            ),
            logo=Element(
                enabled=True,
                order=0,
            ),
            message_before_paying=LabelElement(
                enabled=True,
                label="Please review your payment details",
                order=0,
            ),
            notes=NoteElement(
                enabled=True,
                header="Additional Notes",
                order=0,
                placeholder="Enter any additional notes here",
                value="",
            ),
            page=PageElement(
                description="Get paid securely",
                enabled=True,
                header="Payment Page",
                order=0,
            ),
            payment_button=LabelElement(
                enabled=True,
                label="Pay Now",
                order=0,
            ),
            payment_methods=MethodElement(
                all_methods_checked=True,
                enabled=True,
                header="Payment Methods",
                methods=MethodsList(
                    amex=True,
                    apple_pay=True,
                    discover=True,
                    e_check=True,
                    mastercard=True,
                    visa=True,
                ),
                order=0,
            ),
            payor=PayorElement(
                enabled=True,
                fields=[
                    PayorFields(
                        display=True,
                        fixed=True,
                        identifier=True,
                        label="Full Name",
                        name="fullName",
                        order=0,
                        required=True,
                        validation="^[a-zA-Z ]+$",
                        value="",
                        width=0,
                    )
                ],
                header="Payor Information",
                order=0,
            ),
            review=HeaderElement(
                enabled=True,
                header="Review Payment",
                order=0,
            ),
            settings=PagelinkSetting(
                color="#000000",
                language="en",
            ),
        )
        """
        _response = self._raw_client.add_pay_link_from_bill_lot_number(
            lot_number,
            entry_point=entry_point,
            vendor_number=vendor_number,
            mail_2=mail_2,
            amount_fixed=amount_fixed,
            contact_us=contact_us,
            invoices=invoices,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            payor=payor,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data


class AsyncPaymentLinkClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawPaymentLinkClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawPaymentLinkClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawPaymentLinkClient
        """
        return self._raw_client

    async def add_pay_link_from_invoice(
        self,
        id_invoice: int,
        *,
        amount_fixed: typing.Optional[bool] = None,
        mail_2: typing.Optional[str] = None,
        idempotency_key: typing.Optional[IdempotencyKey] = None,
        contact_us: typing.Optional[ContactElement] = OMIT,
        invoices: typing.Optional[InvoiceElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        payor: typing.Optional[PayorElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Generates a payment link for an invoice from the invoice ID.

        Parameters
        ----------
        id_invoice : int
            Invoice ID

        amount_fixed : typing.Optional[bool]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        idempotency_key : typing.Optional[IdempotencyKey]

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        invoices : typing.Optional[InvoiceElement]
            Invoices section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        payor : typing.Optional[PayorElement]
            Customer/Payor section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import (
            Asyncpayabli,
            ContactElement,
            Element,
            FileContent,
            HeaderElement,
            InvoiceElement,
            LabelElement,
            MethodElement,
            MethodElementSettings,
            MethodElementSettingsApplePay,
            MethodsList,
            NoteElement,
            PageElement,
            PagelinkSetting,
            PayorElement,
            PayorFields,
        )

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.add_pay_link_from_invoice(
                id_invoice=23548884,
                mail_2="jo@example.com; ceo@example.com",
                contact_us=ContactElement(
                    email_label="Email",
                    enabled=True,
                    header="Contact Us",
                    order=0,
                    payment_icons=True,
                    phone_label="Phone",
                ),
                invoices=InvoiceElement(
                    enabled=True,
                    invoice_link=LabelElement(
                        enabled=True,
                        label="View Invoice",
                        order=0,
                    ),
                    order=0,
                    view_invoice_details=LabelElement(
                        enabled=True,
                        label="Invoice Details",
                        order=0,
                    ),
                ),
                logo=Element(
                    enabled=True,
                    order=0,
                ),
                message_before_paying=LabelElement(
                    enabled=True,
                    label="Please review your payment details",
                    order=0,
                ),
                notes=NoteElement(
                    enabled=True,
                    header="Additional Notes",
                    order=0,
                    placeholder="Enter any additional notes here",
                    value="",
                ),
                page=PageElement(
                    description="Complete your payment securely",
                    enabled=True,
                    header="Payment Page",
                    order=0,
                ),
                payment_button=LabelElement(
                    enabled=True,
                    label="Pay Now",
                    order=0,
                ),
                payment_methods=MethodElement(
                    all_methods_checked=True,
                    enabled=True,
                    header="Payment Methods",
                    methods=MethodsList(
                        amex=True,
                        apple_pay=True,
                        discover=True,
                        e_check=True,
                        mastercard=True,
                        visa=True,
                    ),
                    order=0,
                    settings=MethodElementSettings(
                        apple_pay=MethodElementSettingsApplePay(
                            button_style="black",
                            button_type="pay",
                            language="en-US",
                        ),
                    ),
                ),
                payor=PayorElement(
                    enabled=True,
                    fields=[
                        PayorFields(
                            display=True,
                            fixed=True,
                            identifier=True,
                            label="Full Name",
                            name="fullName",
                            order=0,
                            required=True,
                            validation="^[a-zA-Z ]+$",
                            value="",
                            width=0,
                        )
                    ],
                    header="Payor Information",
                    order=0,
                ),
                review=HeaderElement(
                    enabled=True,
                    header="Review Payment",
                    order=0,
                ),
                settings=PagelinkSetting(
                    color="#000000",
                    custom_css_url="https://example.com/custom.css",
                    language="en",
                    page_logo=FileContent(
                        f_content=" ",
                        filename="logo.jpg",
                        ftype="jpg",
                        furl="",
                    ),
                    redirect_after_approve=True,
                    redirect_after_approve_url="https://example.com/success",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_pay_link_from_invoice(
            id_invoice,
            amount_fixed=amount_fixed,
            mail_2=mail_2,
            idempotency_key=idempotency_key,
            contact_us=contact_us,
            invoices=invoices,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            payor=payor,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data

    async def add_pay_link_from_bill(
        self,
        bill_id: int,
        *,
        amount_fixed: typing.Optional[bool] = None,
        mail_2: typing.Optional[str] = None,
        idempotency_key: typing.Optional[IdempotencyKey] = None,
        contact_us: typing.Optional[ContactElement] = OMIT,
        invoices: typing.Optional[InvoiceElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        payor: typing.Optional[PayorElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Generates a payment link for a bill from the bill ID.

        Parameters
        ----------
        bill_id : int
            The Payabli ID for the bill.

        amount_fixed : typing.Optional[bool]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        idempotency_key : typing.Optional[IdempotencyKey]

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        invoices : typing.Optional[InvoiceElement]
            Invoices section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        payor : typing.Optional[PayorElement]
            Customer/Payor section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import (
            Asyncpayabli,
            ContactElement,
            Element,
            HeaderElement,
            LabelElement,
            MethodElement,
            MethodsList,
            NoteElement,
            PageElement,
            PagelinkSetting,
            PayorElement,
            PayorFields,
        )

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.add_pay_link_from_bill(
                bill_id=23548884,
                mail_2="jo@example.com; ceo@example.com",
                contact_us=ContactElement(
                    email_label="Email",
                    enabled=True,
                    header="Contact Us",
                    order=0,
                    payment_icons=True,
                    phone_label="Phone",
                ),
                logo=Element(
                    enabled=True,
                    order=0,
                ),
                message_before_paying=LabelElement(
                    enabled=True,
                    label="Please review your payment details",
                    order=0,
                ),
                notes=NoteElement(
                    enabled=True,
                    header="Additional Notes",
                    order=0,
                    placeholder="Enter any additional notes here",
                    value="",
                ),
                page=PageElement(
                    description="Get paid securely",
                    enabled=True,
                    header="Payment Page",
                    order=0,
                ),
                payment_button=LabelElement(
                    enabled=True,
                    label="Pay Now",
                    order=0,
                ),
                payment_methods=MethodElement(
                    all_methods_checked=True,
                    enabled=True,
                    header="Payment Methods",
                    methods=MethodsList(
                        amex=True,
                        apple_pay=True,
                        discover=True,
                        e_check=True,
                        mastercard=True,
                        visa=True,
                    ),
                    order=0,
                ),
                payor=PayorElement(
                    enabled=True,
                    fields=[
                        PayorFields(
                            display=True,
                            fixed=True,
                            identifier=True,
                            label="Full Name",
                            name="fullName",
                            order=0,
                            required=True,
                            validation="^[a-zA-Z ]+$",
                            value="",
                            width=0,
                        )
                    ],
                    header="Payor Information",
                    order=0,
                ),
                review=HeaderElement(
                    enabled=True,
                    header="Review Payment",
                    order=0,
                ),
                settings=PagelinkSetting(
                    color="#000000",
                    language="en",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_pay_link_from_bill(
            bill_id,
            amount_fixed=amount_fixed,
            mail_2=mail_2,
            idempotency_key=idempotency_key,
            contact_us=contact_us,
            invoices=invoices,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            payor=payor,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data

    async def delete_pay_link_from_id(
        self, pay_link_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> PayabliApiResponsePaymentLinks:
        """
        Deletes a payment link by ID.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.delete_pay_link_from_id(
                pay_link_id="payLinkId",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_pay_link_from_id(pay_link_id, request_options=request_options)
        return _response.data

    async def get_pay_link_from_id(
        self, paylink_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetPayLinkFromIdResponse:
        """
        Retrieves a payment link by ID.

        Parameters
        ----------
        paylink_id : str
            ID for payment link

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetPayLinkFromIdResponse
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.get_pay_link_from_id(
                paylink_id="paylinkId",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_pay_link_from_id(paylink_id, request_options=request_options)
        return _response.data

    async def push_pay_link_from_id(
        self, pay_link_id: str, *, request: PushPayLinkRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> PayabliApiResponsePaymentLinks:
        """
        Send a payment link to the specified email addresses or phone numbers.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        request : PushPayLinkRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli, PushPayLinkRequest_Sms

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.push_pay_link_from_id(
                pay_link_id="payLinkId",
                request=PushPayLinkRequest_Sms(),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.push_pay_link_from_id(
            pay_link_id, request=request, request_options=request_options
        )
        return _response.data

    async def refresh_pay_link_from_id(
        self,
        pay_link_id: str,
        *,
        amount_fixed: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Refresh a payment link's content after an update.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        amount_fixed : typing.Optional[bool]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.refresh_pay_link_from_id(
                pay_link_id="payLinkId",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.refresh_pay_link_from_id(
            pay_link_id, amount_fixed=amount_fixed, request_options=request_options
        )
        return _response.data

    async def send_pay_link_from_id(
        self,
        pay_link_id: str,
        *,
        attachfile: typing.Optional[bool] = None,
        mail_2: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Sends a payment link to the specified email addresses.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        attachfile : typing.Optional[bool]
            When `true`, attaches a PDF version of invoice to the email.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.send_pay_link_from_id(
                pay_link_id="payLinkId",
                mail_2="jo@example.com; ceo@example.com",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.send_pay_link_from_id(
            pay_link_id, attachfile=attachfile, mail_2=mail_2, request_options=request_options
        )
        return _response.data

    async def update_pay_link_from_id(
        self,
        pay_link_id: str,
        *,
        contact_us: typing.Optional[ContactElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Updates a payment link's details.

        Parameters
        ----------
        pay_link_id : str
            ID for the payment link.

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli, LabelElement, NoteElement

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.update_pay_link_from_id(
                pay_link_id="332-c277b704-1301",
                notes=NoteElement(
                    enabled=True,
                    header="Additional Notes",
                    order=0,
                    placeholder="Enter any additional notes here",
                    value="",
                ),
                payment_button=LabelElement(
                    enabled=True,
                    label="Pay Now",
                    order=0,
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_pay_link_from_id(
            pay_link_id,
            contact_us=contact_us,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data

    async def add_pay_link_from_bill_lot_number(
        self,
        lot_number: str,
        *,
        entry_point: Entry,
        vendor_number: str,
        mail_2: typing.Optional[str] = None,
        amount_fixed: typing.Optional[str] = None,
        contact_us: typing.Optional[ContactElement] = OMIT,
        invoices: typing.Optional[InvoiceElement] = OMIT,
        logo: typing.Optional[Element] = OMIT,
        message_before_paying: typing.Optional[LabelElement] = OMIT,
        notes: typing.Optional[NoteElement] = OMIT,
        page: typing.Optional[PageElement] = OMIT,
        payment_button: typing.Optional[LabelElement] = OMIT,
        payment_methods: typing.Optional[MethodElement] = OMIT,
        payor: typing.Optional[PayorElement] = OMIT,
        review: typing.Optional[HeaderElement] = OMIT,
        settings: typing.Optional[PagelinkSetting] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponsePaymentLinks:
        """
        Generates a vendor payment link for a specific bill lot number. This allows you to pay all bills with the same lot number for a vendor with a single payment link.

        Parameters
        ----------
        lot_number : str
            Lot number of the bills to pay. All bills with this lot number will be included.

        entry_point : Entry

        vendor_number : str
            The vendor number for the vendor being paid with this payment link.

        mail_2 : typing.Optional[str]
            List of recipient email addresses. When there is more than one, separate them by a semicolon (;).

        amount_fixed : typing.Optional[str]
            Indicates whether customer can modify the payment amount. A value of `true` means the amount isn't modifiable, a value `false` means the payor can modify the amount to pay.

        contact_us : typing.Optional[ContactElement]
            ContactUs section of payment link page

        invoices : typing.Optional[InvoiceElement]
            Invoices section of payment link page

        logo : typing.Optional[Element]
            Logo section of payment link page

        message_before_paying : typing.Optional[LabelElement]
            Message section of payment link page

        notes : typing.Optional[NoteElement]
            Notes section of payment link page

        page : typing.Optional[PageElement]
            Page header section of payment link page

        payment_button : typing.Optional[LabelElement]
            Payment button section of payment link page

        payment_methods : typing.Optional[MethodElement]
            Payment methods section of payment link page

        payor : typing.Optional[PayorElement]
            Customer/Payor section of payment link page

        review : typing.Optional[HeaderElement]
            Review section of payment link page

        settings : typing.Optional[PagelinkSetting]
            Settings section of payment link page

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponsePaymentLinks
            Success

        Examples
        --------
        import asyncio

        from payabli import (
            Asyncpayabli,
            ContactElement,
            Element,
            HeaderElement,
            LabelElement,
            MethodElement,
            MethodsList,
            NoteElement,
            PageElement,
            PagelinkSetting,
            PayorElement,
            PayorFields,
        )

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.payment_link.add_pay_link_from_bill_lot_number(
                lot_number="LOT-2024-001",
                entry_point="billing",
                vendor_number="VENDOR-123",
                mail_2="customer@example.com; billing@example.com",
                amount_fixed="true",
                contact_us=ContactElement(
                    email_label="Email",
                    enabled=True,
                    header="Contact Us",
                    order=0,
                    payment_icons=True,
                    phone_label="Phone",
                ),
                logo=Element(
                    enabled=True,
                    order=0,
                ),
                message_before_paying=LabelElement(
                    enabled=True,
                    label="Please review your payment details",
                    order=0,
                ),
                notes=NoteElement(
                    enabled=True,
                    header="Additional Notes",
                    order=0,
                    placeholder="Enter any additional notes here",
                    value="",
                ),
                page=PageElement(
                    description="Get paid securely",
                    enabled=True,
                    header="Payment Page",
                    order=0,
                ),
                payment_button=LabelElement(
                    enabled=True,
                    label="Pay Now",
                    order=0,
                ),
                payment_methods=MethodElement(
                    all_methods_checked=True,
                    enabled=True,
                    header="Payment Methods",
                    methods=MethodsList(
                        amex=True,
                        apple_pay=True,
                        discover=True,
                        e_check=True,
                        mastercard=True,
                        visa=True,
                    ),
                    order=0,
                ),
                payor=PayorElement(
                    enabled=True,
                    fields=[
                        PayorFields(
                            display=True,
                            fixed=True,
                            identifier=True,
                            label="Full Name",
                            name="fullName",
                            order=0,
                            required=True,
                            validation="^[a-zA-Z ]+$",
                            value="",
                            width=0,
                        )
                    ],
                    header="Payor Information",
                    order=0,
                ),
                review=HeaderElement(
                    enabled=True,
                    header="Review Payment",
                    order=0,
                ),
                settings=PagelinkSetting(
                    color="#000000",
                    language="en",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_pay_link_from_bill_lot_number(
            lot_number,
            entry_point=entry_point,
            vendor_number=vendor_number,
            mail_2=mail_2,
            amount_fixed=amount_fixed,
            contact_us=contact_us,
            invoices=invoices,
            logo=logo,
            message_before_paying=message_before_paying,
            notes=notes,
            page=page,
            payment_button=payment_button,
            payment_methods=payment_methods,
            payor=payor,
            review=review,
            settings=settings,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .apple_pay_metadata import ApplePayMetadata


class ApplePayStatusData(UniversalBaseModel):
    """
    Details about the Apple Pay service status.
    """

    error_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="errorMessage")] = (
        pydantic.Field(default=None)
    )
    """
    Any error message related to Apple Pay's activation status.
    """

    metadata: typing.Optional[ApplePayMetadata] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..errors.bad_request_error import BadRequestError
from ..errors.internal_server_error import InternalServerError
from ..errors.service_unavailable_error import ServiceUnavailableError
from ..errors.unauthorized_error import UnauthorizedError
from ..types.additional_data import AdditionalData
from ..types.address_addtl_nullable import AddressAddtlNullable
from ..types.address_nullable import AddressNullable
from ..types.billing_data import BillingData
from ..types.contacts_field import ContactsField
from ..types.email import Email
from ..types.location_code import LocationCode
from ..types.mcc import Mcc
from ..types.payabli_api_response import PayabliApiResponse
from ..types.payabli_api_response_vendors import PayabliApiResponseVendors
from ..types.payee_name import PayeeName
from ..types.remit_email import RemitEmail
from ..types.remitaddress_1 import Remitaddress1
from ..types.remitaddress_2 import Remitaddress2
from ..types.remitcity import Remitcity
from ..types.remitcountry import Remitcountry
from ..types.remitstate import Remitstate
from ..types.remitzip import Remitzip
from ..types.vendor_ein import VendorEin
from ..types.vendor_name_1 import VendorName1
from ..types.vendor_name_2 import VendorName2
from ..types.vendor_number import VendorNumber
from ..types.vendor_payment_method_string import VendorPaymentMethodString
from ..types.vendor_phone import VendorPhone
from ..types.vendor_query_record import VendorQueryRecord
from ..types.vendorstatus import Vendorstatus

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawVendorClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def add_vendor(
        self,
        entry: str,
        *,
        vendor_number: typing.Optional[VendorNumber] = OMIT,
        additional_data: typing.Optional[AdditionalData] = OMIT,
        address_1: typing.Optional[AddressNullable] = OMIT,
        address_2: typing.Optional[AddressAddtlNullable] = OMIT,
        billing_data: typing.Optional[BillingData] = OMIT,
        city: typing.Optional[str] = OMIT,
        contacts: typing.Optional[ContactsField] = OMIT,
        country: typing.Optional[str] = OMIT,
        custom_field_1: typing.Optional[str] = OMIT,
        custom_field_2: typing.Optional[str] = OMIT,
        customer_vendor_account: typing.Optional[str] = OMIT,
        ein: typing.Optional[VendorEin] = OMIT,
        email: typing.Optional[Email] = OMIT,
        internal_reference_id: typing.Optional[int] = OMIT,
        location_code: typing.Optional[LocationCode] = OMIT,
        mcc: typing.Optional[Mcc] = OMIT,
        name_1: typing.Optional[VendorName1] = OMIT,
        name_2: typing.Optional[VendorName2] = OMIT,
        payee_name_1: typing.Optional[PayeeName] = OMIT,
        payee_name_2: typing.Optional[PayeeName] = OMIT,
        payment_method: typing.Optional[VendorPaymentMethodString] = OMIT,
        phone: typing.Optional[VendorPhone] = OMIT,
        remit_address_1: typing.Optional[Remitaddress1] = OMIT,
        remit_address_2: typing.Optional[Remitaddress2] = OMIT,
        remit_city: typing.Optional[Remitcity] = OMIT,
        remit_country: typing.Optional[Remitcountry] = OMIT,
        remit_email: typing.Optional[RemitEmail] = OMIT,
        remit_state: typing.Optional[Remitstate] = OMIT,
        remit_zip: typing.Optional[Remitzip] = OMIT,
        state: typing.Optional[str] = OMIT,
        vendor_status: typing.Optional[Vendorstatus] = OMIT,
        zip: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[PayabliApiResponseVendors]:
        """
        Creates a vendor in an entrypoint.

        Parameters
        ----------
        entry : str
            Entrypoint identifier.

        vendor_number : typing.Optional[VendorNumber]

        additional_data : typing.Optional[AdditionalData]

        address_1 : typing.Optional[AddressNullable]
            Vendor's address

        address_2 : typing.Optional[AddressAddtlNullable]
            Additional line for vendor's address.

        billing_data : typing.Optional[BillingData]
            Object containing vendor's bank information.

        city : typing.Optional[str]
            Vendor's city.

        contacts : typing.Optional[ContactsField]
            Array of objects describing the vendor's contacts.

        country : typing.Optional[str]
            Vendor's country.

        custom_field_1 : typing.Optional[str]
            Custom field 1 for vendor

        custom_field_2 : typing.Optional[str]
            Custom field 2 for vendor

        customer_vendor_account : typing.Optional[str]
            Account number of paypoint in the vendor side.

        ein : typing.Optional[VendorEin]

        email : typing.Optional[Email]
            Vendor's email address. Required for vCard.

        internal_reference_id : typing.Optional[int]
            Internal identifier for global vendor account.

        location_code : typing.Optional[LocationCode]

        mcc : typing.Optional[Mcc]

        name_1 : typing.Optional[VendorName1]

        name_2 : typing.Optional[VendorName2]

        payee_name_1 : typing.Optional[PayeeName]

        payee_name_2 : typing.Optional[PayeeName]

        payment_method : typing.Optional[VendorPaymentMethodString]

        phone : typing.Optional[VendorPhone]

        remit_address_1 : typing.Optional[Remitaddress1]

        remit_address_2 : typing.Optional[Remitaddress2]

        remit_city : typing.Optional[Remitcity]

        remit_country : typing.Optional[Remitcountry]

        remit_email : typing.Optional[RemitEmail]

        remit_state : typing.Optional[Remitstate]

        remit_zip : typing.Optional[Remitzip]

        state : typing.Optional[str]
            Vendor's state. Must be a 2 character state code.

        vendor_status : typing.Optional[Vendorstatus]

        zip : typing.Optional[str]
            Vendor's zip code.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[PayabliApiResponseVendors]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Vendor/single/{jsonable_encoder(entry)}",
            method="POST",
            json={
                "vendorNumber": vendor_number,
                "AdditionalData": additional_data,
                "address1": address_1,
                "address2": address_2,
                "billingData": convert_and_respect_annotation_metadata(
                    object_=billing_data, annotation=BillingData, direction="write"
                ),
                "city": city,
                "contacts": convert_and_respect_annotation_metadata(
                    object_=contacts, annotation=ContactsField, direction="write"
                ),
                "country": country,
                "customField1": custom_field_1,
                "customField2": custom_field_2,
                "customerVendorAccount": customer_vendor_account,
                "ein": ein,
                "email": email,
                "internalReferenceId": internal_reference_id,
                "locationCode": location_code,
                "mcc": mcc,
                "name1": name_1,
                "name2": name_2,
                "payeeName1": payee_name_1,
                "payeeName2": payee_name_2,
                "paymentMethod": payment_method,
                "phone": phone,
                "remitAddress1": remit_address_1,
                "remitAddress2": remit_address_2,
                "remitCity": remit_city,
                "remitCountry": remit_country,
                "remitEmail": remit_email,
                "remitState": remit_state,
                "remitZip": remit_zip,
                "state": state,
                "vendorStatus": vendor_status,
                "zip": zip,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PayabliApiResponseVendors,
                    parse_obj_as(
                        type_=PayabliApiResponseVendors,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_vendor(
        self, id_vendor: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[PayabliApiResponseVendors]:
        """
        Delete a vendor.

        Parameters
        ----------
        id_vendor : int
            Vendor ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[PayabliApiResponseVendors]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Vendor/{jsonable_encoder(id_vendor)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PayabliApiResponseVendors,
                    parse_obj_as(
                        type_=PayabliApiResponseVendors,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def edit_vendor(
        self,
        id_vendor: int,
        *,
        vendor_number: typing.Optional[VendorNumber] = OMIT,
        additional_data: typing.Optional[AdditionalData] = OMIT,
        address_1: typing.Optional[AddressNullable] = OMIT,
        address_2: typing.Optional[AddressAddtlNullable] = OMIT,
        billing_data: typing.Optional[BillingData] = OMIT,
        city: typing.Optional[str] = OMIT,
        contacts: typing.Optional[ContactsField] = OMIT,
        country: typing.Optional[str] = OMIT,
        custom_field_1: typing.Optional[str] = OMIT,
        custom_field_2: typing.Optional[str] = OMIT,
        customer_vendor_account: typing.Optional[str] = OMIT,
        ein: typing.Optional[VendorEin] = OMIT,
        email: typing.Optional[Email] = OMIT,
        internal_reference_id: typing.Optional[int] = OMIT,
        location_code: typing.Optional[LocationCode] = OMIT,
        mcc: typing.Optional[Mcc] = OMIT,
        name_1: typing.Optional[VendorName1] = OMIT,
        name_2: typing.Optional[VendorName2] = OMIT,
        payee_name_1: typing.Optional[PayeeName] = OMIT,
        payee_name_2: typing.Optional[PayeeName] = OMIT,
        payment_method: typing.Optional[VendorPaymentMethodString] = OMIT,
        phone: typing.Optional[VendorPhone] = OMIT,
        remit_address_1: typing.Optional[Remitaddress1] = OMIT,
        remit_address_2: typing.Optional[Remitaddress2] = OMIT,
        remit_city: typing.Optional[Remitcity] = OMIT,
        remit_country: typing.Optional[Remitcountry] = OMIT,
        remit_email: typing.Optional[RemitEmail] = OMIT,
        remit_state: typing.Optional[Remitstate] = OMIT,
        remit_zip: typing.Optional[Remitzip] = OMIT,
        state: typing.Optional[str] = OMIT,
        vendor_status: typing.Optional[Vendorstatus] = OMIT,
        zip: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[PayabliApiResponseVendors]:
        """
        Updates a vendor's information. Send only the fields you need to update.

        Parameters
        ----------
        id_vendor : int
            Vendor ID.

        vendor_number : typing.Optional[VendorNumber]

        additional_data : typing.Optional[AdditionalData]

        address_1 : typing.Optional[AddressNullable]
            Vendor's address

        address_2 : typing.Optional[AddressAddtlNullable]
            Additional line for vendor's address.

        billing_data : typing.Optional[BillingData]
            Object containing vendor's bank information.

        city : typing.Optional[str]
            Vendor's city.

        contacts : typing.Optional[ContactsField]
            Array of objects describing the vendor's contacts.

        country : typing.Optional[str]
            Vendor's country.

        custom_field_1 : typing.Optional[str]
            Custom field 1 for vendor

        custom_field_2 : typing.Optional[str]
            Custom field 2 for vendor

        customer_vendor_account : typing.Optional[str]
            Account number of paypoint in the vendor side.

        ein : typing.Optional[VendorEin]

        email : typing.Optional[Email]
            Vendor's email address. Required for vCard.

        internal_reference_id : typing.Optional[int]
            Internal identifier for global vendor account.

        location_code : typing.Optional[LocationCode]

        mcc : typing.Optional[Mcc]

        name_1 : typing.Optional[VendorName1]

        name_2 : typing.Optional[VendorName2]

        payee_name_1 : typing.Optional[PayeeName]

        payee_name_2 : typing.Optional[PayeeName]

        payment_method : typing.Optional[VendorPaymentMethodString]

        phone : typing.Optional[VendorPhone]

        remit_address_1 : typing.Optional[Remitaddress1]

        remit_address_2 : typing.Optional[Remitaddress2]

        remit_city : typing.Optional[Remitcity]

        remit_country : typing.Optional[Remitcountry]

        remit_email : typing.Optional[RemitEmail]

        remit_state : typing.Optional[Remitstate]

        remit_zip : typing.Optional[Remitzip]

        state : typing.Optional[str]
            Vendor's state. Must be a 2 character state code.

        vendor_status : typing.Optional[Vendorstatus]

        zip : typing.Optional[str]
            Vendor's zip code.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[PayabliApiResponseVendors]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Vendor/{jsonable_encoder(id_vendor)}",
            method="PUT",
            json={
                "vendorNumber": vendor_number,
                "AdditionalData": additional_data,
                "address1": address_1,
                "address2": address_2,
                "billingData": convert_and_respect_annotation_metadata(
                    object_=billing_data, annotation=BillingData, direction="write"
                ),
                "city": city,
                "contacts": convert_and_respect_annotation_metadata(
                    object_=contacts, annotation=ContactsField, direction="write"
                ),
                "country": country,
                "customField1": custom_field_1,
                "customField2": custom_field_2,
                "customerVendorAccount": customer_vendor_account,
                "ein": ein,
                "email": email,
                "internalReferenceId": internal_reference_id,
                "locationCode": location_code,
                "mcc": mcc,
                "name1": name_1,
                "name2": name_2,
                "payeeName1": payee_name_1,
                "payeeName2": payee_name_2,
                "paymentMethod": payment_method,
                "phone": phone,
                "remitAddress1": remit_address_1,
                "remitAddress2": remit_address_2,
                "remitCity": remit_city,
                "remitCountry": remit_country,
                "remitEmail": remit_email,
                "remitState": remit_state,
                "remitZip": remit_zip,
                "state": state,
                "vendorStatus": vendor_status,
                "zip": zip,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PayabliApiResponseVendors,
                    parse_obj_as(
                        type_=PayabliApiResponseVendors,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_vendor(
        self, id_vendor: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[VendorQueryRecord]:
        """
        Retrieves a vendor's details.

        Parameters
        ----------
        id_vendor : int
            Vendor ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[VendorQueryRecord]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Vendor/{jsonable_encoder(id_vendor)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    VendorQueryRecord,
                    parse_obj_as(
                        type_=VendorQueryRecord,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawVendorClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def add_vendor(
        self,
        entry: str,
        *,
        vendor_number: typing.Optional[VendorNumber] = OMIT,
        additional_data: typing.Optional[AdditionalData] = OMIT,
        address_1: typing.Optional[AddressNullable] = OMIT,
        address_2: typing.Optional[AddressAddtlNullable] = OMIT,
        billing_data: typing.Optional[BillingData] = OMIT,
        city: typing.Optional[str] = OMIT,
        contacts: typing.Optional[ContactsField] = OMIT,
        country: typing.Optional[str] = OMIT,
        custom_field_1: typing.Optional[str] = OMIT,
        custom_field_2: typing.Optional[str] = OMIT,
        customer_vendor_account: typing.Optional[str] = OMIT,
        ein: typing.Optional[VendorEin] = OMIT,
        email: typing.Optional[Email] = OMIT,
        internal_reference_id: typing.Optional[int] = OMIT,
        location_code: typing.Optional[LocationCode] = OMIT,
        mcc: typing.Optional[Mcc] = OMIT,
        name_1: typing.Optional[VendorName1] = OMIT,
        name_2: typing.Optional[VendorName2] = OMIT,
        payee_name_1: typing.Optional[PayeeName] = OMIT,
        payee_name_2: typing.Optional[PayeeName] = OMIT,
        payment_method: typing.Optional[VendorPaymentMethodString] = OMIT,
        phone: typing.Optional[VendorPhone] = OMIT,
        remit_address_1: typing.Optional[Remitaddress1] = OMIT,
        remit_address_2: typing.Optional[Remitaddress2] = OMIT,
        remit_city: typing.Optional[Remitcity] = OMIT,
        remit_country: typing.Optional[Remitcountry] = OMIT,
        remit_email: typing.Optional[RemitEmail] = OMIT,
        remit_state: typing.Optional[Remitstate] = OMIT,
        remit_zip: typing.Optional[Remitzip] = OMIT,
        state: typing.Optional[str] = OMIT,
        vendor_status: typing.Optional[Vendorstatus] = OMIT,
        zip: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[PayabliApiResponseVendors]:
        """
        Creates a vendor in an entrypoint.

        Parameters
        ----------
        entry : str
            Entrypoint identifier.

        vendor_number : typing.Optional[VendorNumber]

        additional_data : typing.Optional[AdditionalData]

        address_1 : typing.Optional[AddressNullable]
            Vendor's address

        address_2 : typing.Optional[AddressAddtlNullable]
            Additional line for vendor's address.

        billing_data : typing.Optional[BillingData]
            Object containing vendor's bank information.

        city : typing.Optional[str]
            Vendor's city.

        contacts : typing.Optional[ContactsField]
            Array of objects describing the vendor's contacts.

        country : typing.Optional[str]
            Vendor's country.

        custom_field_1 : typing.Optional[str]
            Custom field 1 for vendor

        custom_field_2 : typing.Optional[str]
            Custom field 2 for vendor

        customer_vendor_account : typing.Optional[str]
            Account number of paypoint in the vendor side.

        ein : typing.Optional[VendorEin]

        email : typing.Optional[Email]
            Vendor's email address. Required for vCard.

        internal_reference_id : typing.Optional[int]
            Internal identifier for global vendor account.

        location_code : typing.Optional[LocationCode]

        mcc : typing.Optional[Mcc]

        name_1 : typing.Optional[VendorName1]

        name_2 : typing.Optional[VendorName2]

        payee_name_1 : typing.Optional[PayeeName]

        payee_name_2 : typing.Optional[PayeeName]

        payment_method : typing.Optional[VendorPaymentMethodString]

        phone : typing.Optional[VendorPhone]

        remit_address_1 : typing.Optional[Remitaddress1]

        remit_address_2 : typing.Optional[Remitaddress2]

        remit_city : typing.Optional[Remitcity]

        remit_country : typing.Optional[Remitcountry]

        remit_email : typing.Optional[RemitEmail]

        remit_state : typing.Optional[Remitstate]

        remit_zip : typing.Optional[Remitzip]

        state : typing.Optional[str]
            Vendor's state. Must be a 2 character state code.

        vendor_status : typing.Optional[Vendorstatus]

        zip : typing.Optional[str]
            Vendor's zip code.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[PayabliApiResponseVendors]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Vendor/single/{jsonable_encoder(entry)}",
            method="POST",
            json={
                "vendorNumber": vendor_number,
                "AdditionalData": additional_data,
                "address1": address_1,
                "address2": address_2,
                "billingData": convert_and_respect_annotation_metadata(
                    object_=billing_data, annotation=BillingData, direction="write"
                ),
                "city": city,
                "contacts": convert_and_respect_annotation_metadata(
                    object_=contacts, annotation=ContactsField, direction="write"
                ),
                "country": country,
                "customField1": custom_field_1,
                "customField2": custom_field_2,
                "customerVendorAccount": customer_vendor_account,
                "ein": ein,
                "email": email,
                "internalReferenceId": internal_reference_id,
                "locationCode": location_code,
                "mcc": mcc,
                "name1": name_1,
                "name2": name_2,
                "payeeName1": payee_name_1,
                "payeeName2": payee_name_2,
                "paymentMethod": payment_method,
                "phone": phone,
                "remitAddress1": remit_address_1,
                "remitAddress2": remit_address_2,
                "remitCity": remit_city,
                "remitCountry": remit_country,
                "remitEmail": remit_email,
                "remitState": remit_state,
                "remitZip": remit_zip,
                "state": state,
                "vendorStatus": vendor_status,
                "zip": zip,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PayabliApiResponseVendors,
                    parse_obj_as(
                        type_=PayabliApiResponseVendors,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_vendor(
        self, id_vendor: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[PayabliApiResponseVendors]:
        """
        Delete a vendor.

        Parameters
        ----------
        id_vendor : int
            Vendor ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[PayabliApiResponseVendors]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Vendor/{jsonable_encoder(id_vendor)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PayabliApiResponseVendors,
                    parse_obj_as(
                        type_=PayabliApiResponseVendors,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def edit_vendor(
        self,
        id_vendor: int,
        *,
        vendor_number: typing.Optional[VendorNumber] = OMIT,
        additional_data: typing.Optional[AdditionalData] = OMIT,
        address_1: typing.Optional[AddressNullable] = OMIT,
        address_2: typing.Optional[AddressAddtlNullable] = OMIT,
        billing_data: typing.Optional[BillingData] = OMIT,
        city: typing.Optional[str] = OMIT,
        contacts: typing.Optional[ContactsField] = OMIT,
        country: typing.Optional[str] = OMIT,
        custom_field_1: typing.Optional[str] = OMIT,
        custom_field_2: typing.Optional[str] = OMIT,
        customer_vendor_account: typing.Optional[str] = OMIT,
        ein: typing.Optional[VendorEin] = OMIT,
        email: typing.Optional[Email] = OMIT,
        internal_reference_id: typing.Optional[int] = OMIT,
        location_code: typing.Optional[LocationCode] = OMIT,
        mcc: typing.Optional[Mcc] = OMIT,
        name_1: typing.Optional[VendorName1] = OMIT,
        name_2: typing.Optional[VendorName2] = OMIT,
        payee_name_1: typing.Optional[PayeeName] = OMIT,
        payee_name_2: typing.Optional[PayeeName] = OMIT,
        payment_method: typing.Optional[VendorPaymentMethodString] = OMIT,
        phone: typing.Optional[VendorPhone] = OMIT,
        remit_address_1: typing.Optional[Remitaddress1] = OMIT,
        remit_address_2: typing.Optional[Remitaddress2] = OMIT,
        remit_city: typing.Optional[Remitcity] = OMIT,
        remit_country: typing.Optional[Remitcountry] = OMIT,
        remit_email: typing.Optional[RemitEmail] = OMIT,
        remit_state: typing.Optional[Remitstate] = OMIT,
        remit_zip: typing.Optional[Remitzip] = OMIT,
        state: typing.Optional[str] = OMIT,
        vendor_status: typing.Optional[Vendorstatus] = OMIT,
        zip: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[PayabliApiResponseVendors]:
        """
        Updates a vendor's information. Send only the fields you need to update.

        Parameters
        ----------
        id_vendor : int
            Vendor ID.

        vendor_number : typing.Optional[VendorNumber]

        additional_data : typing.Optional[AdditionalData]

        address_1 : typing.Optional[AddressNullable]
            Vendor's address

        address_2 : typing.Optional[AddressAddtlNullable]
            Additional line for vendor's address.

        billing_data : typing.Optional[BillingData]
            Object containing vendor's bank information.

        city : typing.Optional[str]
            Vendor's city.

        contacts : typing.Optional[ContactsField]
            Array of objects describing the vendor's contacts.

        country : typing.Optional[str]
            Vendor's country.

        custom_field_1 : typing.Optional[str]
            Custom field 1 for vendor

        custom_field_2 : typing.Optional[str]
            Custom field 2 for vendor

        customer_vendor_account : typing.Optional[str]
            Account number of paypoint in the vendor side.

        ein : typing.Optional[VendorEin]

        email : typing.Optional[Email]
            Vendor's email address. Required for vCard.

        internal_reference_id : typing.Optional[int]
            Internal identifier for global vendor account.

        location_code : typing.Optional[LocationCode]

        mcc : typing.Optional[Mcc]

        name_1 : typing.Optional[VendorName1]

        name_2 : typing.Optional[VendorName2]

        payee_name_1 : typing.Optional[PayeeName]

        payee_name_2 : typing.Optional[PayeeName]

        payment_method : typing.Optional[VendorPaymentMethodString]

        phone : typing.Optional[VendorPhone]

        remit_address_1 : typing.Optional[Remitaddress1]

        remit_address_2 : typing.Optional[Remitaddress2]

        remit_city : typing.Optional[Remitcity]

        remit_country : typing.Optional[Remitcountry]

        remit_email : typing.Optional[RemitEmail]

        remit_state : typing.Optional[Remitstate]

        remit_zip : typing.Optional[Remitzip]

        state : typing.Optional[str]
            Vendor's state. Must be a 2 character state code.

        vendor_status : typing.Optional[Vendorstatus]

        zip : typing.Optional[str]
            Vendor's zip code.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[PayabliApiResponseVendors]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Vendor/{jsonable_encoder(id_vendor)}",
            method="PUT",
            json={
                "vendorNumber": vendor_number,
                "AdditionalData": additional_data,
                "address1": address_1,
                "address2": address_2,
                "billingData": convert_and_respect_annotation_metadata(
                    object_=billing_data, annotation=BillingData, direction="write"
                ),
                "city": city,
                "contacts": convert_and_respect_annotation_metadata(
                    object_=contacts, annotation=ContactsField, direction="write"
                ),
                "country": country,
                "customField1": custom_field_1,
                "customField2": custom_field_2,
                "customerVendorAccount": customer_vendor_account,
                "ein": ein,
                "email": email,
                "internalReferenceId": internal_reference_id,
                "locationCode": location_code,
                "mcc": mcc,
                "name1": name_1,
                "name2": name_2,
                "payeeName1": payee_name_1,
                "payeeName2": payee_name_2,
                "paymentMethod": payment_method,
                "phone": phone,
                "remitAddress1": remit_address_1,
                "remitAddress2": remit_address_2,
                "remitCity": remit_city,
                "remitCountry": remit_country,
                "remitEmail": remit_email,
                "remitState": remit_state,
                "remitZip": remit_zip,
                "state": state,
                "vendorStatus": vendor_status,
                "zip": zip,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PayabliApiResponseVendors,
                    parse_obj_as(
                        type_=PayabliApiResponseVendors,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_vendor(
        self, id_vendor: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[VendorQueryRecord]:
        """
        Retrieves a vendor's details.

        Parameters
        ----------
        id_vendor : int
            Vendor ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[VendorQueryRecord]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Vendor/{jsonable_encoder(id_vendor)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    VendorQueryRecord,
                    parse_obj_as(
                        type_=VendorQueryRecord,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .bill_pay_out_data import BillPayOutData
from .comments import Comments
from .created_at import CreatedAt
from .dbaname import Dbaname
from .entrypointfield import Entrypointfield
from .external_paypoint_id import ExternalPaypointId
from .fee_amount import FeeAmount
from .file_content import FileContent
from .gatewayfield import Gatewayfield
from .has_vcard_transactions import HasVcardTransactions
from .is_same_day_ach import IsSameDayAch
from .last_modified import LastModified
from .legalname import Legalname
from .netamountnullable import Netamountnullable
from .org_parent_name import OrgParentName
from .orgid import Orgid
from .payment_id_string import PaymentIdString
from .payout_program import PayoutProgram
from .query_payment_data import QueryPaymentData
from .query_transaction_events import QueryTransactionEvents
from .risk_action import RiskAction
from .risk_action_code import RiskActionCode
from .risk_flagged import RiskFlagged
from .risk_flagged_on import RiskFlaggedOn
from .risk_reason import RiskReason
from .risk_status import RiskStatus
from .schedule_id import ScheduleId
from .settlement_status_payout import SettlementStatusPayout
from .source import Source
from .vendor_query_record import VendorQueryRecord


class TransactionOutQueryRecord(UniversalBaseModel):
    id_out: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="IdOut")] = pydantic.Field(
        default=None
    )
    """
    Identifier of payout transaction.
    """

    created_at: typing_extensions.Annotated[typing.Optional[CreatedAt], FieldMetadata(alias="CreatedAt")] = None
    comments: typing_extensions.Annotated[typing.Optional[Comments], FieldMetadata(alias="Comments")] = pydantic.Field(
        default=None
    )
    """
    Any comment or description for payout transaction.
    """

    vendor: typing_extensions.Annotated[typing.Optional[VendorQueryRecord], FieldMetadata(alias="Vendor")] = (
        pydantic.Field(default=None)
    )
    """
    Vendor related to the payout transaction.
    """

    paypoint_dbaname: typing_extensions.Annotated[typing.Optional[Dbaname], FieldMetadata(alias="PaypointDbaname")] = (
        None
    )
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname], FieldMetadata(alias="PaypointLegalname")
    ] = None
    status: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="Status")] = pydantic.Field(
        default=None
    )
    """
    Internal status of transaction.
    """

    last_updated: typing_extensions.Annotated[typing.Optional[LastModified], FieldMetadata(alias="LastUpdated")] = (
        pydantic.Field(default=None)
    )
    """
    Timestamp when payment record was updated, in UTC.
    """

    total_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="TotalAmount")] = (
        pydantic.Field(default=None)
    )
    """
    Transaction total amount (including service fee or sub-charge).
    """

    net_amount: typing_extensions.Annotated[typing.Optional[Netamountnullable], FieldMetadata(alias="NetAmount")] = None
    fee_amount: typing_extensions.Annotated[typing.Optional[FeeAmount], FieldMetadata(alias="FeeAmount")] = None
    source: typing_extensions.Annotated[typing.Optional[Source], FieldMetadata(alias="Source")] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName")
    ] = None
    parent_org_id: typing_extensions.Annotated[typing.Optional[Orgid], FieldMetadata(alias="ParentOrgId")] = None
    batch_number: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BatchNumber")] = (
        pydantic.Field(default=None)
    )
    """
    The batch number for the payout transaction.
    """

    payment_status: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="PaymentStatus")] = (
        pydantic.Field(default=None)
    )
    """
    Status of payout transaction.
    """

    payment_method: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="PaymentMethod")] = (
        pydantic.Field(default=None)
    )
    """
    Method of payment applied to the transaction.
    """

    card_token: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="CardToken")] = None
    check_number: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="CheckNumber")] = (
        pydantic.Field(default=None)
    )
    """
    Paper check number related to payout transaction.
    """

    check_data: typing_extensions.Annotated[typing.Optional[FileContent], FieldMetadata(alias="CheckData")] = (
        pydantic.Field(default=None)
    )
    """
    Object referencing to paper check image.
    """

    payment_id: typing_extensions.Annotated[typing.Optional[PaymentIdString], FieldMetadata(alias="PaymentId")] = None
    payment_data: typing_extensions.Annotated[typing.Optional[QueryPaymentData], FieldMetadata(alias="PaymentData")] = (
        None
    )
    bills: typing_extensions.Annotated[typing.Optional[typing.List[BillPayOutData]], FieldMetadata(alias="Bills")] = (
        pydantic.Field(default=None)
    )
    """
    Events associated to this transaction.
    """

    events: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryTransactionEvents]], FieldMetadata(alias="Events")
    ] = pydantic.Field(default=None)
    """
    Events associated to this transaction.
    """

    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId], FieldMetadata(alias="externalPaypointID")
    ] = None
    entry_name: typing_extensions.Annotated[typing.Optional[Entrypointfield], FieldMetadata(alias="EntryName")] = None
    gateway: typing_extensions.Annotated[typing.Optional[Gatewayfield], FieldMetadata(alias="Gateway")] = None
    batch_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BatchId")] = pydantic.Field(
        default=None
    )
    """
    ID of the batch the transaction belongs to.
    """

    has_vcard_transactions: typing_extensions.Annotated[
        typing.Optional[HasVcardTransactions], FieldMetadata(alias="HasVcardTransactions")
    ] = None
    is_same_day_ach: typing_extensions.Annotated[typing.Optional[IsSameDayAch], FieldMetadata(alias="IsSameDayACH")] = (
        None
    )
    schedule_id: typing_extensions.Annotated[typing.Optional[ScheduleId], FieldMetadata(alias="ScheduleId")] = None
    settlement_status: typing_extensions.Annotated[
        typing.Optional[SettlementStatusPayout], FieldMetadata(alias="SettlementStatus")
    ] = None
    risk_flagged: typing_extensions.Annotated[typing.Optional[RiskFlagged], FieldMetadata(alias="RiskFlagged")] = None
    risk_flagged_on: typing_extensions.Annotated[
        typing.Optional[RiskFlaggedOn], FieldMetadata(alias="RiskFlaggedOn")
    ] = None
    risk_status: typing_extensions.Annotated[typing.Optional[RiskStatus], FieldMetadata(alias="RiskStatus")] = None
    risk_reason: typing_extensions.Annotated[typing.Optional[RiskReason], FieldMetadata(alias="RiskReason")] = None
    risk_action: typing_extensions.Annotated[typing.Optional[RiskAction], FieldMetadata(alias="RiskAction")] = None
    risk_action_code: typing_extensions.Annotated[
        typing.Optional[RiskActionCode], FieldMetadata(alias="RiskActionCode")
    ] = None
    payout_program: typing_extensions.Annotated[
        typing.Optional[PayoutProgram], FieldMetadata(alias="PayoutProgram")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .query_boarding_links_response_records_item import QueryBoardingLinksResponseRecordsItem
from .query_summary import QuerySummary


class QueryBoardingLinksResponse(UniversalBaseModel):
    """ """

    records: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryBoardingLinksResponseRecordsItem]], FieldMetadata(alias="Records")
    ] = None
    summary: typing_extensions.Annotated[typing.Optional[QuerySummary], FieldMetadata(alias="Summary")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .key_value_duo import KeyValueDuo
from .notification_content_event_type import NotificationContentEventType
from .notification_content_file_format import NotificationContentFileFormat
from .notification_content_report_name import NotificationContentReportName
from .timezone import Timezone


class NotificationContent(UniversalBaseModel):
    event_type: typing_extensions.Annotated[
        typing.Optional[NotificationContentEventType], FieldMetadata(alias="eventType")
    ] = pydantic.Field(default=None)
    """
    The notification's event name.
    """

    file_format: typing_extensions.Annotated[
        typing.Optional[NotificationContentFileFormat], FieldMetadata(alias="fileFormat")
    ] = pydantic.Field(default=None)
    """
    Indicate the format of report file to be generated by the engine.
    Used for `method` = *report-email* and *report-web*.
    """

    internal_data: typing_extensions.Annotated[
        typing.Optional[typing.List[KeyValueDuo]], FieldMetadata(alias="internalData")
    ] = pydantic.Field(default=None)
    """
    Array of pairs key:value to insert in request body to target in **method** = *web* or *report-web*.
    """

    report_name: typing_extensions.Annotated[
        typing.Optional[NotificationContentReportName], FieldMetadata(alias="reportName")
    ] = pydantic.Field(default=None)
    """
    The kind report to generate. For [automated reports](/developers/developer-guides/notifications-and-webhooks-overview#automated-reports) only.
    """

    time_zone: typing_extensions.Annotated[typing.Optional[Timezone], FieldMetadata(alias="timeZone")] = None
    transaction_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="transactionId")] = (
        pydantic.Field(default=None)
    )
    """
    Used internally to reference the entity or object generating the event.
    """

    web_header_parameters: typing_extensions.Annotated[
        typing.Optional[typing.List[KeyValueDuo]], FieldMetadata(alias="webHeaderParameters")
    ] = pydantic.Field(default=None)
    """
    Array of pairs key:value to insert in header of request to target in **method** = *web* or *report-web*.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.api_error import ApiError
from ..types.payabli_api_response_paylinks import PayabliApiResponsePaylinks


class ConflictError(ApiError):
    def __init__(self, body: PayabliApiResponsePaylinks, headers: typing.Optional[typing.Dict[str, str]] = None):
        super().__init__(status_code=409, headers=headers, body=body)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .bank_account_holder_name import BankAccountHolderName
from .bank_account_holder_type import BankAccountHolderType
from .bank_name import BankName
from .routing_account import RoutingAccount
from .type_account import TypeAccount


class BillingData(UniversalBaseModel):
    account_number: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="accountNumber")] = (
        pydantic.Field(default=None)
    )
    """
    Account number for bank account.
    """

    bank_account_function: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="bankAccountFunction")
    ] = pydantic.Field(default=None)
    """
    Describes whether the bank account is used for deposits or withdrawals in Payabli:
      - `0`: Deposit
      - `1`: Withdrawal 
      - `2`: Deposit and withdrawal
    """

    bank_account_holder_name: typing_extensions.Annotated[
        typing.Optional[BankAccountHolderName], FieldMetadata(alias="bankAccountHolderName")
    ] = None
    bank_account_holder_type: typing_extensions.Annotated[
        typing.Optional[BankAccountHolderType], FieldMetadata(alias="bankAccountHolderType")
    ] = None
    bank_name: typing_extensions.Annotated[typing.Optional[BankName], FieldMetadata(alias="bankName")] = None
    id: typing.Optional[int] = pydantic.Field(default=None)
    """
    The bank's ID in Payabli.
    """

    routing_account: typing_extensions.Annotated[
        typing.Optional[RoutingAccount], FieldMetadata(alias="routingAccount")
    ] = None
    type_account: typing_extensions.Annotated[typing.Optional[TypeAccount], FieldMetadata(alias="typeAccount")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .bank_section import BankSection
from .document_section_terms_and_conditions import DocumentSectionTermsAndConditions
from .signer_section import SignerSection
from .sub_footer import SubFooter
from .sub_header import SubHeader
from .visible import Visible


class DocumentSection(UniversalBaseModel):
    visble: typing.Optional[Visible] = None
    sub_footer: typing_extensions.Annotated[typing.Optional[SubFooter], FieldMetadata(alias="subFooter")] = None
    sub_header: typing_extensions.Annotated[typing.Optional[SubHeader], FieldMetadata(alias="subHeader")] = None
    deposit_bank: typing_extensions.Annotated[typing.Optional[BankSection], FieldMetadata(alias="depositBank")] = None
    minimum_documents: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="minimumDocuments")] = (
        pydantic.Field(default=None)
    )
    """
    The minimum number of documents the applicant must upload with the application.
    """

    upload_documents: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="uploadDocuments")] = (
        pydantic.Field(default=None)
    )
    """
    When `true`, allows the applicant to upload documents to the application.
    """

    bank_data: typing_extensions.Annotated[typing.Optional[BankSection], FieldMetadata(alias="bankData")] = None
    terms_and_conditions: typing_extensions.Annotated[
        typing.Optional[DocumentSectionTermsAndConditions], FieldMetadata(alias="termsAndConditions")
    ] = None
    signer: typing.Optional[SignerSection] = None
    visible: typing.Optional[Visible] = None
    withdrawal_bank: typing_extensions.Annotated[
        typing.Optional[BankSection], FieldMetadata(alias="withdrawalBank")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .page_identifier import PageIdentifier
from .pagesize import Pagesize
from .totalpages import Totalpages
from .totalrecords import Totalrecords


class BillQueryResponseSummary(UniversalBaseModel):
    pageidentifier: typing.Optional[PageIdentifier] = None
    page_size: typing_extensions.Annotated[typing.Optional[Pagesize], FieldMetadata(alias="pageSize")] = None
    total_2_approval: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="total2approval")] = None
    totalactive: typing.Optional[int] = None
    total_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="totalAmount")] = (
        pydantic.Field(default=None)
    )
    """
    Total amount of bills in response.
    """

    totalamount_2_approval: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="totalamount2approval")
    ] = None
    totalamountactive: typing.Optional[float] = None
    totalamountapproved: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total amount of approved bills.
    """

    totalamountcancel: typing.Optional[float] = None
    totalamountdisapproved: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total amount of disapproved bills.
    """

    totalamountintransit: typing.Optional[float] = None
    totalamountoverdue: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total amount of bills that are overdue.
    """

    totalamountpaid: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total amount of paid bills.
    """

    totalamountsent_2_approval: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="totalamountsent2approval")
    ] = None
    totalapproved: typing.Optional[int] = pydantic.Field(default=None)
    """
    The total number of bills that were approved.
    """

    totalcancel: typing.Optional[int] = None
    totaldisapproved: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of bills that were disapproved.
    """

    totalintransit: typing.Optional[int] = None
    totaloverdue: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of bills that are overdue.
    """

    total_pages: typing_extensions.Annotated[typing.Optional[Totalpages], FieldMetadata(alias="totalPages")] = None
    totalpaid: typing.Optional[int] = pydantic.Field(default=None)
    """
    The total number of paid bills.
    """

    total_records: typing_extensions.Annotated[typing.Optional[Totalrecords], FieldMetadata(alias="totalRecords")] = (
        None
    )
    totalsent_2_approval: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="totalsent2approval")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .ach_holder import AchHolder
from .ach_holder_type import AchHolderType
from .ach_sec_code import AchSecCode
from .achaccount import Achaccount
from .achaccounttype import Achaccounttype
from .achrouting import Achrouting
from .device import Device


class PayMethodAch(UniversalBaseModel):
    ach_account: typing_extensions.Annotated[Achaccount, FieldMetadata(alias="achAccount")] = pydantic.Field()
    """
    Bank account number. This field is **required** when method = 'ach'.
    """

    ach_account_type: typing_extensions.Annotated[
        typing.Optional[Achaccounttype], FieldMetadata(alias="achAccountType")
    ] = pydantic.Field(default=None)
    """
    Bank account type. This field is **required** when method = 'ach'.
    """

    ach_code: typing_extensions.Annotated[typing.Optional[AchSecCode], FieldMetadata(alias="achCode")] = None
    ach_holder: typing_extensions.Annotated[AchHolder, FieldMetadata(alias="achHolder")]
    ach_holder_type: typing_extensions.Annotated[
        typing.Optional[AchHolderType], FieldMetadata(alias="achHolderType")
    ] = None
    ach_routing: typing_extensions.Annotated[Achrouting, FieldMetadata(alias="achRouting")] = pydantic.Field()
    """
    ABA/routing number of bank account. This field is **required** when method = 'ach'.
    """

    device: typing.Optional[Device] = None
    method: typing.Literal["ach"] = "ach"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .amount_element import AmountElement
from .auto_element import AutoElement
from .contact_element import ContactElement
from .element import Element
from .header_element import HeaderElement
from .invoice_element import InvoiceElement
from .label_element import LabelElement
from .method_element import MethodElement
from .note_element import NoteElement
from .page_element import PageElement
from .payor_element import PayorElement
from .subdomain import Subdomain


class PageContent(UniversalBaseModel):
    amount: typing.Optional[AmountElement] = pydantic.Field(default=None)
    """
    Amount section of payment page
    """

    autopay: typing.Optional[AutoElement] = pydantic.Field(default=None)
    """
    Autopay section of payment page
    """

    contact_us: typing_extensions.Annotated[typing.Optional[ContactElement], FieldMetadata(alias="contactUs")] = (
        pydantic.Field(default=None)
    )
    """
    ContactUs section of payment page
    """

    entry: typing.Optional[str] = pydantic.Field(default=None)
    """
    Identifier of entry point owner of page
    """

    invoices: typing.Optional[InvoiceElement] = pydantic.Field(default=None)
    """
    Invoices section of payment page
    """

    logo: typing.Optional[Element] = pydantic.Field(default=None)
    """
    Logo section of payment page
    """

    message_before_paying: typing_extensions.Annotated[
        typing.Optional[LabelElement], FieldMetadata(alias="messageBeforePaying")
    ] = pydantic.Field(default=None)
    """
    Message section of payment page
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Descriptor of page
    """

    notes: typing.Optional[NoteElement] = pydantic.Field(default=None)
    """
    Notes section of payment page
    """

    page: typing.Optional[PageElement] = pydantic.Field(default=None)
    """
    Page header section of payment page
    """

    payment_button: typing_extensions.Annotated[typing.Optional[LabelElement], FieldMetadata(alias="paymentButton")] = (
        pydantic.Field(default=None)
    )
    """
    Payment button section of payment page
    """

    payment_methods: typing_extensions.Annotated[
        typing.Optional[MethodElement], FieldMetadata(alias="paymentMethods")
    ] = pydantic.Field(default=None)
    """
    Payment methods section of payment page
    """

    payor: typing.Optional[PayorElement] = pydantic.Field(default=None)
    """
    Customer/Payor section of payment page
    """

    review: typing.Optional[HeaderElement] = pydantic.Field(default=None)
    """
    Review section of payment page
    """

    subdomain: typing.Optional[Subdomain] = pydantic.Field(default=None)
    """
    Unique identifier assigned to the page.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .address_addtl_nullable import AddressAddtlNullable
from .address_nullable import AddressNullable
from .bank_data import BankData
from .boarding_id import BoardingId
from .city_nullable import CityNullable
from .contacts_field import ContactsField
from .country_nullable import CountryNullable
from .dbaname import Dbaname
from .external_paypoint_id import ExternalPaypointId
from .idpaypoint import Idpaypoint
from .legalname import Legalname
from .org_data import OrgData
from .payabli_credentials_pascal import PayabliCredentialsPascal
from .paypoint_summary import PaypointSummary
from .paypointstatus import Paypointstatus
from .phone_number import PhoneNumber
from .services import Services
from .state_nullable import StateNullable
from .timezone import Timezone
from .website import Website
from .zip import Zip


class PaypointData(UniversalBaseModel):
    address_1: typing_extensions.Annotated[typing.Optional[AddressNullable], FieldMetadata(alias="address1")] = None
    address_2: typing_extensions.Annotated[typing.Optional[AddressAddtlNullable], FieldMetadata(alias="address2")] = (
        None
    )
    bank_data: typing_extensions.Annotated[typing.Optional[BankData], FieldMetadata(alias="bankData")] = None
    boarding_id: typing_extensions.Annotated[typing.Optional[BoardingId], FieldMetadata(alias="boardingId")] = None
    city: typing.Optional[CityNullable] = None
    contacts: typing.Optional[ContactsField] = None
    country: typing.Optional[CountryNullable] = None
    credentials: typing.Optional[typing.List[PayabliCredentialsPascal]] = None
    dba_name: typing_extensions.Annotated[typing.Optional[Dbaname], FieldMetadata(alias="dbaName")] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId], FieldMetadata(alias="externalPaypointID")
    ] = None
    fax: typing.Optional[PhoneNumber] = pydantic.Field(default=None)
    """
    Fax number
    """

    id_paypoint: typing_extensions.Annotated[typing.Optional[Idpaypoint], FieldMetadata(alias="idPaypoint")] = None
    legal_name: typing_extensions.Annotated[typing.Optional[Legalname], FieldMetadata(alias="legalName")] = None
    parent_org: typing_extensions.Annotated[typing.Optional[OrgData], FieldMetadata(alias="parentOrg")] = None
    paypoint_status: typing_extensions.Annotated[
        typing.Optional[Paypointstatus], FieldMetadata(alias="paypointStatus")
    ] = None
    phone: typing.Optional[PhoneNumber] = None
    service_data: typing_extensions.Annotated[typing.Optional[Services], FieldMetadata(alias="serviceData")] = None
    state: typing.Optional[StateNullable] = None
    summary: typing.Optional[PaypointSummary] = None
    time_zone: typing_extensions.Annotated[typing.Optional[Timezone], FieldMetadata(alias="timeZone")] = None
    website_address: typing_extensions.Annotated[typing.Optional[Website], FieldMetadata(alias="websiteAddress")] = None
    zip: typing.Optional[Zip] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.accountid import Accountid
from ...types.entrypointfield import Entrypointfield
from ...types.order_id import OrderId
from ...types.orderdescription import Orderdescription
from ...types.source import Source
from ...types.subdomain import Subdomain
from ...types.subscriptionid import Subscriptionid
from .authorize_payment_method import AuthorizePaymentMethod
from .request_out_authorize_invoice_data import RequestOutAuthorizeInvoiceData
from .request_out_authorize_payment_details import RequestOutAuthorizePaymentDetails
from .request_out_authorize_vendor_data import RequestOutAuthorizeVendorData


class AuthorizePayoutBody(UniversalBaseModel):
    entry_point: typing_extensions.Annotated[Entrypointfield, FieldMetadata(alias="entryPoint")]
    source: typing.Optional[Source] = None
    order_id: typing_extensions.Annotated[typing.Optional[OrderId], FieldMetadata(alias="orderId")] = None
    order_description: typing_extensions.Annotated[
        typing.Optional[Orderdescription], FieldMetadata(alias="orderDescription")
    ] = None
    payment_method: typing_extensions.Annotated[AuthorizePaymentMethod, FieldMetadata(alias="paymentMethod")]
    payment_details: typing_extensions.Annotated[
        RequestOutAuthorizePaymentDetails, FieldMetadata(alias="paymentDetails")
    ] = pydantic.Field()
    """
    Object containing payment details.
    """

    vendor_data: typing_extensions.Annotated[RequestOutAuthorizeVendorData, FieldMetadata(alias="vendorData")] = (
        pydantic.Field()
    )
    """
    Object containing vendor data.
    """

    invoice_data: typing_extensions.Annotated[
        typing.List[RequestOutAuthorizeInvoiceData], FieldMetadata(alias="invoiceData")
    ] = pydantic.Field()
    """
    Array of bills associated to the transaction
    """

    account_id: typing_extensions.Annotated[typing.Optional[Accountid], FieldMetadata(alias="accountId")] = None
    subdomain: typing.Optional[Subdomain] = None
    subscription_id: typing_extensions.Annotated[
        typing.Optional[Subscriptionid], FieldMetadata(alias="subscriptionId")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .split_funding_content import SplitFundingContent

SplitFunding = typing.Optional[typing.List[SplitFundingContent]]
